####################################
TensorFlow Integrated MLTSA module
####################################

These are the functions that are integrated with tensorflow for MLTSA and training of ML models and the models creation
and integration onto the code.

.. automodule:: MLTSA_tf
   :members:

.. automodule:: TF_2_MLP
   :members:

.. automodule:: TF_2_LSTM
   :members:

.. automodule:: TF_2_RNN
   :members:

.. automodule:: TF_old_LSTM
   :members:

.. automodule:: TF_old_MLP
   :members:

